@@ -2,7 +2,10 @@ from abc import ABC, abstractmethod
 
 
 class ModuleInterface(ABC):
-    """Module interface class for ui component handling."""
+    """
+    Interface class to implement all FlaUI wrapper modules from Python to C#.
+    Module package contains all component implementations from FlaUI usage.
+    """
 
     @abstractmethod
     def execute_action(self, action, values=None):
@@ -12,4 +15,4 @@ class ModuleInterface(ABC):
             action (Action): Specific action to call for execution.
             values (Object): Parameter values to use for method execution.
         """
-        raise NotImplementedError('Subclasses must override execute_action method')
+        raise NotImplementedError('Subclass must override execute_action method')
